breakingchanges

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 17, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateExemptionsFile

func CreateExemptionsFile(outputPath, exemptionsPath string, ignoreExpiration bool, fs afero.Fs) error

CreateExemptionsFile generates a file with the exemptions in the oasdiff breaking changes format.

Types

type Exemption

type Exemption struct {
	BreakingChangeDescription string `yaml:"breaking_change_description"`
	ExemptUntil               string `yaml:"exempt_until"`
	Reason                    string `yaml:"reason"`
	HideFromChangelog         string `yaml:"hide_from_changelog,omitempty"`
}

func GetHiddenExemptions

func GetHiddenExemptions(exemptions []Exemption) []Exemption

GetHiddenExemptions returns a list of exemptions that have 'HideFromChangelog' set to true.

func GetValidExemptionsList

func GetValidExemptionsList(exemptionsPath string, ignoreExpiration bool, fs afero.Fs) ([]Exemption, error)

GetValidExemptionsList returns a list of exemptions. If ignoreExpiration is set to true, it will return all exemptions.

Jump to